"""
Meta-Features are classes that extend :class:`~revscoring.Datasource` and
implement common operations on other :class:`~revscoring.Datasource`.

dicts
+++++
.. automodule:: revscoring.datasources.meta.dicts

extractors
++++++++++
.. automodule:: revscoring.datasources.meta.extractors

filters
+++++++
.. automodule:: revscoring.datasources.meta.filters

frequencies
+++++++++++
.. automodule:: revscoring.datasources.meta.frequencies

gramming
++++++++
.. automodule:: revscoring.datasources.meta.gramming

hashing
+++++++
.. automodule:: revscoring.datasources.meta.hashing

indexable
+++++++++
.. automodule:: revscoring.datasources.meta.indexable

mappers
+++++++
.. automodule:: revscoring.datasources.meta.mappers

selectors
+++++++++
.. automodule:: revscoring.datasources.meta.selectors

timestamp
+++++++++
.. automodule:: revscoring.datasources.meta.timestamp
"""
